camelot.camelot.view.controls.navpane

Package camelot :: Package camelot :: Package view :: Package controls :: Module navpane |
[hide private]
[frames] | no frames]

# Module navpane

source code

left navigation pane

Classes | [hide private]
| PaneCaption Navigation pane Caption
| PaneButton Custom made navigation pane pushbutton
| NavigationPane ms office-like navigation pane in Qt

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.controls.navpane')`
| QT_MAJOR_VERSION = `float('.'.join(str(QtCore.QT_VERSION_STR).s`...``
| _ = `lambda x:`

Variables Details | [hide private]

  ### QT_MAJOR_VERSION Value:
      float('.'.join(str(QtCore.QT_VERSION_STR).split('.') [0: 2]))